@@ -3,7 +3,6 @@ from flask import Blueprint, request, Response
 from ..handlers.mock_handler import MockHandler
 from ..handlers.proxy_handler import ProxyHandler
 from ..handlers.duplicate_header_key_handler import DuplicateHeaderKeyHandler
-from ..handlers.http_header_helper import HeadersHelper
 from ..handlers.path_not_found_handler import RequestPathNotFound
 from ..handlers.handler_context import HandlerContext
 from ..handlers.flow_editor_handler import FlowEditorHandler
@@ -74,8 +73,10 @@ def index(path=''):
             req_context.update_response_data2flow(output_key='proxy_response')
 
     DuplicateHeaderKeyHandler.set_origin_header(resp.headers, req_context.flow['response']['headers'])
-    HeadersHelper.save_raw_location(resp.headers)
 
     context.emit('action', 'add flow log')
 
+    # Close autocorrect response location.
+    resp.autocorrect_location_header = False
+
     return resp
