@@ -54,8 +54,13 @@ class Application:
         self.cache = cache.get_cache()
         self.work_mode = Mode.NORMAL
         self.is_diff_mode = MockMode.NORMAL
-        self.filters = []
-        self.selected_filter = None
+        self.default_filter = {
+            'name': 'All',
+            'desc': 'Display all requests',
+            'ignore': []
+        }
+        self.filters = [self.default_filter]
+        self.selected_filter = self.default_filter
         self.data_manager = DataManager()
         # SocketIO
         self.socket_io: SocketIO = None
@@ -81,7 +86,7 @@ class Application:
             self.is_diff_mode = MockMode.MULTIPLE
 
         if _conf.get('inspector.filters'):
-            self.filters = _conf.get('inspector.filters')
+            self.filters.extend(_conf.get('inspector.filters'))
 
         default_filter = _conf.get('inspector.default_filter')
         for f in self.filters:
@@ -111,7 +116,7 @@ class Application:
     def save(self):
         DEFAULT_CONF = os.path.join(
             os.path.join(os.path.expanduser('~'), '.lyrebird'), 'conf.json')
-        # TODO Lyrebird 的 conf.json 应该有恢复机制或补救措施。
+        # TODO Lyrebird 的 conf.json 应该有恢复机制或补救措施。
         with codecs.open(DEFAULT_CONF, 'w', 'utf-8') as f:
             f.write(json.dumps(self._conf, ensure_ascii=False, indent=4))
 
