@@ -5,9 +5,11 @@ import time
 import socket
 import tarfile
 import requests
+import datetime
 from pathlib import Path
 from contextlib import closing
 from lyrebird.log import get_logger
+from lyrebird.mock.dm.jsonpath import jsonpath
 
 logger = get_logger()
 
@@ -61,6 +63,15 @@ def is_target_match_patterns(pattern_list, target):
     return False
 
 
+def is_jsonpath_match_patterns(pattern_list, json_obj, target_rule):
+    target_nodes = jsonpath.search(json_obj, target_rule)
+    for node in target_nodes:
+        is_match = is_target_match_patterns(pattern_list, node.node)
+        if is_match:
+            return True
+    return False
+
+
 def find_free_port():
     with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
         s.bind(('', 0))
@@ -156,3 +167,19 @@ class TargetMatch:
     @staticmethod
     def _match_null(target, pattern):
         return target == pattern
+
+
+class JSONFormat:
+
+    def json(self):
+        prop_collection = {}
+        props = dir(self)
+        for prop in props:
+            if prop.startswith('_'):
+                continue
+            prop_obj = getattr(self, prop)
+            if isinstance(prop_obj, (str, int, bool, float)):
+                prop_collection[prop] = prop_obj
+            elif isinstance(prop_obj, datetime.datetime):
+                prop_collection[prop] = prop_obj.timestamp()
+        return prop_collection
